@@ -19,6 +19,9 @@ extensions = [
     "sphinx_paramlinks",
     "sphinx_panels",
     "nbsphinx",
+    # For some reason, the following extensions are not working
+    # "IPython.sphinxext.ipython_directive",
+    # "IPython.sphinxext.ipython_console_highlighting",
 ]
 source_suffix = [".rst", ".md"]
 html_theme = "pydata_sphinx_theme"
@@ -27,22 +30,40 @@ html_css_files = [
     "css/custom.css",
 ]
 html_logo = "_static/blosc-logo_256.png"
-html_favicon = "_static/blosc-logo_128.png"
+# Just use the favicon from the parent project
+# html_favicon = "_static/blosc-logo_128.png"
+html_favicon = "_static/blosc-favicon_64x64.png"
 html_theme_options = {
     "logo": {
         "link": "/index",
         "alt_text": "Blosc",
     },
+    "icon_links": [
+        {
+            "name": "GitHub",
+            "url": "https://github.com/Blosc/python-blosc2",
+            "icon": "fab fa-github-square",
+        },
+        {
+            "name": "Mastodon",
+            "url": "https://fosstodon.org/@Blosc2",
+            "icon": "fab fa-mastodon",
+        },
+        {
+            "name": "Bluesky",
+            "url": "https://bsky.app/profile/blosc.org",
+            "icon": "fas fa-cloud-sun",
+        },
+    ],
     "external_links": [
         {"name": "C-Blosc2", "url": "/c-blosc2/c-blosc2.html"},
-        {"name": "Python-Blosc", "url": "/python-blosc/python-blosc.html"},
-        {"name": "Blosc In Depth", "url": "/pages/blosc-in-depth/"},
+        {"name": "Python-Blosc2", "url": "/python-blosc2/"},
         {"name": "Donate to Blosc", "url": "/pages/donate/"},
     ],
-    "github_url": "https://github.com/Blosc/python-blosc2",
-    "twitter_url": "https://twitter.com/Blosc2",
 }
 
+exclude_patterns = ["_build", ".DS_Store", "**.ipynb_checkpoints"]
+
 html_show_sourcelink = False
 
 autosummary_generate_overwrite = False
