@@ -12,7 +12,7 @@ import blosc2
 
 
 @pytest.mark.parametrize(
-    "shape, chunks, blocks, fill_value",
+    ("shape", "chunks", "blocks", "fill_value"),
     [
         ((1, 1230), (1, 100), (1, 3), b"0123"),
         ((23, 1, 1, 34), (20, 1, 1, 20), None, 1234),
